=== modified file 'bzrlib/tests/test_server.py'
--- bzrlib/tests/test_server.py	2010-02-09 17:08:38 +0000
+++ bzrlib/tests/test_server.py	2010-02-09 17:13:04 +0000
@@ -68,6 +68,33 @@
         return urlutils.local_path_to_url('')
 
 
+class MemoryServer(Server):
+    """Server for the MemoryTransport for testing with."""
+
+    def start_server(self):
+        self._dirs = {'/':None}
+        self._files = {}
+        self._locks = {}
+        self._scheme = "memory+%s:///" % id(self)
+        def memory_factory(url):
+            from bzrlib.transport import memory
+            result = memory.MemoryTransport(url)
+            result._dirs = self._dirs
+            result._files = self._files
+            result._locks = self._locks
+            return result
+        self._memory_factory = memory_factory
+        transport.register_transport(self._scheme, self._memory_factory)
+
+    def stop_server(self):
+        # unregister this server
+        transport.unregister_transport(self._scheme, self._memory_factory)
+
+    def get_url(self):
+        """See bzrlib.transport.Server.get_url."""
+        return self._scheme
+
+
 class DecoratorServer(Server):
     """Server for the TransportDecorator for testing with.
 

=== modified file 'bzrlib/transport/memory.py'
--- bzrlib/transport/memory.py	2010-01-08 17:28:25 +0000
+++ bzrlib/transport/memory.py	2010-02-09 17:13:04 +0000
@@ -28,6 +28,7 @@
 import warnings
 
 from bzrlib import (
+    transport,
     urlutils,
     )
 from bzrlib.errors import (
@@ -42,10 +43,6 @@
     AppendBasedFileStream,
     _file_streams,
     LateReadError,
-    register_transport,
-    Server,
-    Transport,
-    unregister_transport,
     )
 
 
@@ -64,7 +61,7 @@
             self.st_mode = S_IFDIR | perms
 
 
-class MemoryTransport(Transport):
+class MemoryTransport(transport.Transport):
     """This is an in memory file system for transient data storage."""
 
     def __init__(self, url=""):
@@ -303,33 +300,8 @@
         self.transport = None
 
 
-class MemoryServer(Server):
-    """Server for the MemoryTransport for testing with."""
-
-    def start_server(self):
-        self._dirs = {'/':None}
-        self._files = {}
-        self._locks = {}
-        self._scheme = "memory+%s:///" % id(self)
-        def memory_factory(url):
-            result = MemoryTransport(url)
-            result._dirs = self._dirs
-            result._files = self._files
-            result._locks = self._locks
-            return result
-        self._memory_factory = memory_factory
-        register_transport(self._scheme, self._memory_factory)
-
-    def stop_server(self):
-        # unregister this server
-        unregister_transport(self._scheme, self._memory_factory)
-
-    def get_url(self):
-        """See bzrlib.transport.Server.get_url."""
-        return self._scheme
-
-
 def get_test_permutations():
     """Return the permutations to be used in testing."""
-    return [(MemoryTransport, MemoryServer),
+    from bzrlib.tests import test_server
+    return [(MemoryTransport, test_server.MemoryServer),
             ]

